@@ -1,6 +1,7 @@
 import asyncio
 import json
 import logging
+from typing import Callable, Coroutine, Optional
 
 from aiohttp import web
 
@@ -34,8 +35,12 @@ def create_webhook_app(bot_runners: list[BotRunner], base_url: str) -> web.Appli
 
     background_tasks: list[asyncio.Task] = []
 
+    app = web.Application()
+    # see https://docs.python.org/3/library/asyncio-task.html#asyncio.create_task
+    app["background_tasks"] = background_tasks
+
     async def setup(_):
-        loop = asyncio.get_event_loop()
+        loop = asyncio.get_running_loop()
         for subroute, br in bot_runner_by_subroute.items():
             await br.bot.delete_webhook()
             await br.bot.set_webhook(url=base_url + ROUTE_TEMPLATE.format(subroute=subroute))
@@ -43,18 +48,17 @@ def create_webhook_app(bot_runners: list[BotRunner], base_url: str) -> web.Appli
         for bw in bot_runners:
             for idx, coro in enumerate(bw.background_jobs):
                 background_tasks.append(loop.create_task(coro))
-                logger.info(f"Background task #{idx} created for {bw.name}")
+                logger.info(f"Background task created for {bw.name} (#{idx})")
 
     async def cleanup(_):
         await api.session_manager.close_session()
         for t in background_tasks:
             t.cancel()
+        await asyncio.gather(*background_tasks)
 
-    app = web.Application()
     app.on_startup.append(setup)
     app.on_cleanup.append(cleanup)
     app.router.add_post(ROUTE_TEMPLATE, webhook_handler)
-
     return app
 
 
